<?php


/**
 * Class Tribe__Events__Ical_Importer__Admin__Notice__Failed_Recurring_Imports
 *
 */
class Tribe__Events__Ical_Importer__Admin__Notice__Failed_Recurring_Imports {

	/**
	 * @var static
	 */
	protected static $instance;

	/**
	 * @var string
	 */
	public static $last_notice_id_option_name = 'tribe_events_ical_importer_failed_recurring_imports_last_notice_id';

	/**
	 * @var string
	 */
	protected $last_notice_id;

	/**
	 * @var string
	 */
	protected $template = '';

	/**
	 * The class singleton constructor.
	 *
	 * @return Tribe__Events__Ical_Importer__Admin__Notice__Failed_Recurring_Imports
	 */
	public static function instance() {
		if ( empty( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Tribe__Events__Ical_Importer__Admin__Notice__Failed_Recurring_Imports constructor.
	 */
	public function __construct() {
		$this->template = <<<HTML
			<div class="error notice tribe-dismiss-notice is-dismissible " data-ref="%s">
				<p>%s</p>
			</div>
HTML;
	}

	/**
	 * Echoes the failed recurring imports notice markup to the page.
	 *
	 * @param bool $return Whether the notice markup should be returned or printed to the page. Defaults to `false`.
	 */
	public function maybe_display( $return = false ) {
		$failed = Tribe__Events__Ical_Importer__Recurring_Imports::get_instance()->get_failed_recurring_imports();

		if ( empty( $failed ) ) {
			return false;
		}

		sort( $failed );
		$count = count( $failed );
		$url   = Tribe__Events__Ical_Importer__Main::instance()->get_url();

		$notice_id = implode( '', $failed );

		$dismissed_notices = get_user_meta( get_current_user_id(), 'tribe-dismiss-notice' );

		if ( in_array( $notice_id, $dismissed_notices ) ) {
			return false;
		}

		update_option( self::$last_notice_id_option_name, $notice_id );

		$message_template = _n( '%s saved import did not complete.', '%s saved imports did not complete.', $count, 'tribe-events-ical-importer' );
		$link             = '| <a href="' . $url . '#tribe-events-ical-saved-imports">' . __( 'click to view', 'tribe-events-ical-importer' ) . '</a>';
		$message          = sprintf( "{$message_template} %s", $count, $link );

		$markup = sprintf( $this->template, $notice_id, $message );

		if ( $return ) {
			return $markup;
		}

		echo $markup;
	}

	/**
	 * Conditionally dismisses a dismissible admin notice for the current user.
	 *
	 * @return bool|string Either the dismissed notice id or `false` if no notice has been dismissed,
	 *                     there was no notice to dismiss or the notice had been dismissed already for
	 *                     the current user.
	 */
	public function maybe_dismiss() {
		$last_notice_id = $this->last_notice_id();

		if ( empty( $last_notice_id ) || empty( $_GET['tribe-dismiss-notice'] ) || $_GET['tribe-dismiss-notice'] !== $last_notice_id ) {
			return false;
		}

		$dismissed_notices = get_user_meta( get_current_user_id(), 'tribe-dismiss-notice' );

		if ( in_array( $last_notice_id, $dismissed_notices ) ) {
			return false;
		}

		add_user_meta( get_current_user_id(), 'tribe-dismiss-notice', $last_notice_id, false );

		return $last_notice_id;
	}

	/**
	 * @return string
	 */
	protected function last_notice_id() {
		if ( empty( $this->last_notice_id ) ) {
			$this->last_notice_id = get_option( self::$last_notice_id_option_name, '' );
		}

		return $this->last_notice_id;
	}
}
