<?php

// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( class_exists( 'Tribe__Events__Importer__Ajax' ) ) {
	return;
}

/**
 * Tribe Events Importer Ajax
 *
 * Extended by Tribe__Events__Importer__Importer to handle the ajax
 *
 * @package Tribe__Events__Importer__Importer
 *
 */
abstract class Tribe__Events__Importer__Ajax {

	/**
	 * Ajax Actions
	 *
	 * Add the neccesary ajax actions
	 *
	 * @uses called via Tribe__Events__Importer__Importer->_addActions()
	 *
	 * @return void
	 */
	public function _ajax_actions() {
		if ( defined( 'DOING_AJAX' ) && DOING_AJAX && empty( $GLOBALS['hook_suffix'] ) ){
			$GLOBALS['hook_suffix'] = 'tribe_ajax';
		}

		add_action( 'wp_ajax_tribe_events_' . $this->pluginSlug . '_get_possible_events', array( $this, 'ajaxGetPossibleEvents' ) );

		add_action( 'wp_ajax_tribe_events_' . $this->pluginSlug . '_save_import_query', array( $this, 'ajaxSaveImportQuery' ) );
		add_action( 'wp_ajax_tribe_events_' . $this->pluginSlug . '_run_saved_import_query', array( $this, 'ajaxRunSavedImportQuery' ) );
		add_action( 'wp_ajax_tribe_events_' . $this->pluginSlug . '_delete_saved_import_query', array( $this, 'ajaxDeleteSavedImportQuery' ) );


		add_action( 'wp_ajax_tribe_events_' . $this->pluginSlug . '_import_checked_events', array( $this, 'ajaxImportCheckedEvents' ) );
		add_action( 'wp_ajax_tribe_events_' . $this->pluginSlug . '_import_all_events', array( $this, 'ajaxImportAllEvents' ) );
	}

	/**
	 * AJAX import all events in a query.
	 *
	 *
	 *
	 *
	 * @return void
	 */
	public function ajaxImportAllEvents() {

		check_ajax_referer( 'ical-import-nonce' );

		$num_imported_events = $this->processImportSubmission();

		wp_send_json( $num_imported_events );
	}


	/**
	 * Save the import query using AJAX.
	 *
	 *
	 * @return void
	 */
	public function ajaxSaveImportQuery() {
		check_ajax_referer( 'ical-import-nonce' );

		if ( isset( $_POST['schedule'] ) && $_POST['schedule'] != '' ) {
			$saved_import = Tribe__Events__Ical_Importer__Recurring_Imports::get_instance()->saveImportQuery();
		}
		$scheduled = false;
		if ( $saved_import ) {
			$scheduled = Tribe__Events__Ical_Importer__Recurring_Imports::get_instance()->scheduleImportQuery( $saved_import );
		}
		if ( $scheduled ) {
			$this->response['body'] = true;
		} else {
			$this->response['error'][] = 'Could not save query.';
		}
		wp_send_json( $this->response );
	}

	/**
	 * Ajax Run Saved Import Query
	 *
	 * Run all imports checked in the saved imports table
	 *
	 * @return void
	 */
	public function ajaxRunSavedImportQuery() {
		check_ajax_referer( 'ical-import-nonce' );

		$count    = 0;
		$updated  = 0;
		$inserted = 0;
		$scanned  = 0;
		$results  = array();

		if ( ! empty( $_POST['index'] ) ) {
			if ( ! is_array( $_POST['index'] ) ) {
				$results[] = Tribe__Events__Ical_Importer__Recurring_Imports::get_instance()->runSavedImportQuery( $_POST['index'] );
				$count++;
			} else {
				foreach ( $_POST['index'] as $index ) {
					$results[] = Tribe__Events__Ical_Importer__Recurring_Imports::get_instance()->runSavedImportQuery( $index );
					$count++;
				}
			}
		}

		// Total the number of events scanned, updated and inserted
		foreach ( $results as $result_set ) {
			// It's possible the result set contains an error - no point counting if so
			if ( empty( $result_set[ 'scanned' ] ) || ! empty( $result_set[ 'error' ] ) ) {
				continue;
			}

			$updated  += $result_set[ 'updated' ];
			$inserted += $result_set[ 'inserted' ];
			$scanned  += $result_set[ 'scanned' ];
		}

		if ( $count != 0 ) {
			$this->response['success']    = $count;
			$this->response['num_events'] = $scanned;
			$this->response['upserts']    = $updated + $inserted;
		} else {
			$this->response['error'][] = 'Could not run the query.';
		}

		wp_send_json( $this->response );
	}

	/**
	 * Ajax Delete Saved Import Query
	 *
	 * Delete the saved import query using AJAX.
	 *
	 * @return void
	 */
	public function ajaxDeleteSavedImportQuery() {
		check_ajax_referer( 'ical-import-nonce' );

		$count = 0;
		$deleted = false;

		if ( ! empty( $_POST['index'] ) ) {
			if ( ! is_array( $_POST['index'] ) ) {
				$deleted = Tribe__Events__Ical_Importer__Recurring_Imports::get_instance()->deleteSavedImportQuery( $_POST['index'] );
				$count++;
			} else {
				$deleted = true;
				foreach ( $_POST['index'] as $index ) {
					$success = Tribe__Events__Ical_Importer__Recurring_Imports::get_instance()->deleteSavedImportQuery( $index );
					if ( ! $success ) {
						$deleted = false;
					}
					$count++;
				}
			}
		}

		if ( $deleted ) {
			$this->response['success'] = $count;
		} else {
			$this->response['error'][] = 'Could not delete the query.';
		}
		wp_send_json( $this->response );
	}

	/**
	 * AJAX import checked events.
	 *
	 *
	 * @return void
	 */
	public function ajaxImportCheckedEvents() {

		check_ajax_referer( 'ical-import-nonce' );

		if ( isset( $_POST['events_to_import'] ) ) {

			$num_imported_events = $this->processImportSubmission();

			wp_send_json( $num_imported_events );
		}
	}

	/**
	 * Ajax Get Possible Events
	 *
	 * Gets events using AJAX and echo them as a json object
	 *
	 * @uses self::getEventsData()
	 *
	 * @return void
	 */
	public function ajaxGetPossibleEvents() {
		$possible_events = $this->getEventsData();

		if ( is_wp_error( $possible_events ) ) {
			$this->errors[] = $possible_events->errors[1][0];
			unset( $possible_events );
		}

		if ( empty( $possible_events ) ) {
			if ( ! $this->errors ) {
				$this->errors[] = __( 'Your search returned no events.', 'tribe-events-ical-importer' );				}
			$errors = array(
				'error' => $this->errors,
			);
			wp_send_json( $errors );
		}

		$this->response['count'] = count( $possible_events );
		$this->response['body'] = $this->buildPossibleEventsListItems( $possible_events );
		$this->response['previous_request'] = $_POST;

		wp_send_json( $this->response );
	}
}
