<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( class_exists( 'Tribe__Events__Ical_Importer__Filter_Bar' ) ) {
	return;
}

/**
 * Tribe Events iCal Importer Filter Bar
 *
 * Allow filtering by events source via filter bar
 *
 * @package Tribe__Events__Ical_Importer__Main
 *
 */
class Tribe__Events__Ical_Importer__Filter_Bar extends Tribe__Events__Filterbar__Filter {

	/**
	 * Type
	 *
	 * The input field type
	 *
	 * @var string
	 */
	public $type = 'select';


	/**
	 * Get Values
	 *
	 * Retrieve the existing ical sources
	 *
	 * @return array
	 *
	 */
	protected function get_values() {
		global $wpdb;

		$sources = Tribe__Events__Ical_Importer__Filters::icalSourcesGet();

		if ( empty( $sources ) ) {
			return array();
		}

		$clean = array();
		foreach ( $sources as $source ) {
			$clean[] = array(
				'name' => $source,
				'value' => $source,
			);
		}

		return $clean;
	}


    /**
	 * Setup Join Clause
	 *
	 * Build a join part of the query to include the ical source
	 *
	 * @uses $wpdb
	 *
	 * @return void
	 */
	protected function setup_join_clause() {
		global $wpdb;

		$clause = $wpdb->prepare( "LEFT JOIN {$wpdb->postmeta} AS ical_filter ON ({$wpdb->posts}.ID = ical_filter.post_id AND ical_filter.meta_key = %s)", Tribe__Events__Ical_Importer__Filters::IMPORTED_META_KEY );

		$this->joinClause = $clause;
	}

	/**
	 * Setup Where Clause
	 *
	 * Build a where part of the query to include the ical source
	 *
	 * @uses $wpdb
	 *
	 * @return void
	 */
	protected function setup_where_clause() {
		global $wpdb;

		$clause = $wpdb->prepare( ' AND ical_filter.meta_value = %s ', $this->currentValue );

		$this->whereClause = $clause;
	}

	/**
	 * Init
	 *
	 * Construct this class using it's parents constructor to add the iCal Source
	 * To the filter bar
	 *
	 * @uses TribeEventsFilter
	 *
	 * @return void
	 */
	public static function init() {
		new self( __( 'iCal Source', 'tribe-events-ical-importer' ), Tribe__Events__Ical_Importer__Filters::IMPORTED_META_KEY );
	}

}
