<?php


class Tribe__Events__Ical_Importer__General_Settings {

	/**
	 * @var Tribe__Events__Ical_Importer__General_Settings
	 */
	protected static $instance;

	/**
	 * The class singleton constructor.
	 *
	 * @return Tribe__Events__Ical_Importer__General_Settings
	 */
	public static function instance() {
		if ( empty( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * @param array $available_fields
	 *
	 * @return array
	 */
	public function add_import_available_fields( array $available_fields ) {
		$available_fields[] = 'ical_import_enable_GoogleMaps';

		return $available_fields;
	}

	/**
	 * @param array $fields
	 *
	 * @return array
	 */
	public function add_settings_fields( $fields = array() ) {
		$newfields = array(
			'ical-title'                 => array(
				'type' => 'html',
				'html' => '<h3>' . esc_html__( 'iCal Import Settings', 'tribe-events-ical-importer' ) . '</h3>',
			),
			'ical-form-content-start'    => array(
				'type' => 'html',
				'html' => '<div class="tribe-settings-form-wrap">',
			),
			'imported_post_status[ical]' => array(
				'type'            => 'dropdown',
				'label'           => __( 'Default status to use for imported events', 'tribe-events-ical-importer' ),
				'options'         => Tribe__Events__Importer__Options::get_possible_stati(),
				'validation_type' => 'options',
				'parent_option'   => Tribe__Events__Main::OPTIONNAME,
				'importer_type'   => 'ical',
			),
			'ical_import_enable_GoogleMaps'     => array(
				'type'            => 'checkbox_bool',
				'label'           => __( 'Enable Google Maps on imported events', 'tribe-events-ical-importer' ),
				'tooltip'         => __( 'Check to enable maps for imported events in the frontend. This will apply to events that have a location or venue set in the original iCal feed or file. Please enable Google Maps on the "General" tab to ensure your events will have map options.',
					'tribe-fb-import' ),
				'default'         => '1',
				'validation_type' => 'boolean',
			),
			'ical-form-content-end'      => array(
				'type' => 'html',
				'html' => '</div>',
			),
		);

		return array_merge( $fields, $newfields );
	}
}
