<?php

// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( class_exists( 'Tribe__Events__Importer__Gui' ) ) {
	return;
}

/**
 * Tribe Events Importer Gui
 *
 * Extended by Tribe__Events__Importer__Importer to handle the admin gui
 *
 * @package Tribe__Events__Importer__Importer
 *
 */
abstract class Tribe__Events__Importer__Gui extends Tribe__Events__Importer__Ajax {

	/**
	 * messages
	 *
	 * Notices to display
	 *
	 * @var array
	 */
	protected $messages = array();


	/**
	 * Gui Actions
	 *
	 * Add the necessary Gui actions
	 *
	 * @uses called via Tribe__Events__Importer__Importer->_addActions()
	 *
	 * @return void
	 */
	public function _gui_actions() {
		if ( ! $this->should_show_admin_notices() ) {
			return;
		}

		add_action( 'admin_notices', array( $this, 'displayMessages' ) );
		add_action( 'admin_notices', array( $this, 'displayErrors' ) );
	}


	/**
	 * Display errors messages.
	 *
	 *
	 * @return void
	 */
	public function displayErrors() {
		if ( isset( $this->errors ) && is_array( $this->errors ) ) {
			foreach ( $this->errors as $error ) {
				?>
				<div class="error">
					<p>
						<?php echo $error; ?>
					</p>
				</div>
				<?php
			}
		}
	}


	/**
	 * Display Messages
	 *
	 * Display notification messages based on the url args.
	 *
	 * @return void
	 */
	public function displayMessages() {

		if ( ! empty( $_REQUEST[ 'edit_recurring' ] ) ) {
			$this->messages[] = __(  'Saved recurring import has been updated.', 'tribe-events-ical-importer' );
		}

		if ( ! empty( $_REQUEST[ 'inserted' ] ) ) {
			if ( ! empty( $_REQUEST[ 'expected' ] ) ) {
				if ( ! empty( $_REQUEST[ 'recurring' ] ) ) {
					$message = __( 'Recurring event import has successfully begun. ', 'tribe-events-ical-importer' );
				} else {
					$message = __( 'Event import has successfully begun. ', 'tribe-events-ical-importer' );
				}

				$message .= sprintf( _n( '%1$s event%2$s has been created, ', '%1$s events%2$s have been created, ', $_REQUEST[ 'inserted' ], 'tribe-events-ical-importer' ), '<strong>' . $_REQUEST[ 'inserted' ], '</strong>' );

				$message .= sprintf( _n( '%1$s event%2$s is currently being imported in batches.', '%1$s events%2$s are currently being imported in batches.', $_REQUEST[ 'expected' ], 'tribe-events-ical-importer' ), '<strong>'. $_REQUEST[ 'expected' ], '</strong>' );

				$this->messages[ ] = $message;

			} else {
				$message = '<p>' . sprintf( _n( '%s event successfully inserted.', '%s events successfully inserted.', $_REQUEST[ 'inserted' ], 'tribe-events-ical-importer' ), $_REQUEST[ 'inserted' ], $_REQUEST[ 'inserted' ] ) . '</p>';
				$message .= '<p>Any recurring events have been imported as multiple single event instances.</p>';
				$this->messages[] = $message;

			}
		}

		if ( ! empty( $_REQUEST[ 'updated' ] ) ) {
			if ( ! empty( $_REQUEST[ 'expected' ] ) && empty( $_REQUEST[ 'inserted' ] ) ) {
				if ( ! empty( $_REQUEST[ 'recurring' ] ) ) {
					$message = __( 'Recurring event import has successfully begun. ', 'tribe-events-ical-importer' );
				} else {
					$message = __( 'Event import has successfully begun. ', 'tribe-events-ical-importer' );
				}

				$message .= sprintf( _n( '%1$s event%2$s has been updated, ', '%1$s events%2$s have been updated, ', $_REQUEST[ 'updated' ], 'tribe-events-ical-importer' ), '<strong>' . $_REQUEST[ 'updated' ], '</strong>' );

				$message .= sprintf( _n( '%1$s event%2$s is currently being updated in batches.', '%1$s events%2$s are currently being updated in batches.', $_REQUEST[ 'expected' ], 'tribe-events-ical-importer' ), '<strong>' . $_REQUEST[ 'expected' ], '</strong>' );

				$this->messages[ ] = $message;

			} else {
				$this->messages[] = sprintf( _n( '%s event successfully updated.', '%s events successfully updated.', $_REQUEST[ 'updated' ], 'tribe-events-ical-importer' ), $_REQUEST[ 'updated' ], $_REQUEST[ 'updated' ] );
			}
		}


		if ( ! empty( $_REQUEST['run_saved_import'] ) ) {
			if ( $_REQUEST['num_events'] == 0 ) {
				$this->messages[] =
					sprintf( _n( '%s saved import successfully ran, but no events found.', '%s saved imports successfully ran, but no events found.', $_REQUEST['run_saved_import'], 'tribe-events-ical-importer' ), $_REQUEST['run_saved_import'], $_REQUEST['run_saved_import'] );
			} elseif ( isset( $_REQUEST['upserts'] ) ) {
				$found = sprintf(
					_n( '%d event was found', '%d events were found', $_REQUEST['num_events'], 'tribe-events-ical-importer' ),
					$_REQUEST['num_events']
				);

				$updated = sprintf(
					_n( 'and %d event was created or updated.', 'and %d events were created or updated.', $_REQUEST['upserts'], 'tribe-events-ical-importer' ),
					$_REQUEST['upserts']
				);

				$this->messages[] = sprintf( _x( '%1$s %2$s', 'saved import update: found and updated event counts', 'tribe-events-ical-importer' ), $found, $updated );
			}
		}

		if ( ! empty( $_REQUEST['deleted_saved_import'] ) ) {
			$this->messages[] = sprintf( _n( '%s saved import successfully deleted.', '%s saved imports successfully deleted.', $_REQUEST['deleted_saved_import'], 'tribe-events-ical-importer' ), $_REQUEST['deleted_saved_import'], $_REQUEST['deleted_saved_import'] );
		}

		if ( ! empty( $_REQUEST['new_saved_import'] ) ) {
			$this->messages[] = sprintf( _n( '%s saved import successfully added.', '%s saved imports successfully added.', $_REQUEST['new_saved_import'], 'tribe-events-ical-importer' ), $_REQUEST['new_saved_import'], $_REQUEST['new_saved_import'] );
		}


		if ( isset( $this->messages ) && is_array( $this->messages ) ) {
			foreach ( $this->messages as $message ) {
				?>
				<div class="updated">
					<p>
						<?php echo $message; ?>
					</p>
				</div>
				<?php
			}
		}
	}

	/**
	 * Whether admin notices should be shown or not.
	 *
	 * @return bool
	 */
	private function should_show_admin_notices() {
		$is_doing_ajax = defined( 'DOING_AJAX' ) && DOING_AJAX === true;
		if ( ! is_admin() || $is_doing_ajax ) {
			return false;
		}

		global $pagenow;
		$editing_events        = $pagenow === 'edit.php' && ! empty( $_GET['post_type'] ) && $_GET['post_type'] === Tribe__Events__Main::POSTTYPE;
		$is_on_importers_page  = ! empty( $_GET['page'] ) && $_GET['page'] === 'events-importer';
		$is_ical_importer_page = $editing_events && $is_on_importers_page;
		if ( ! $is_ical_importer_page ) {
			return false;
		}

		return true;
	}
}
