<?php
// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( class_exists( 'Tribe__Events__Ical_Importer__Possible_Events_List_Table' ) ) {
	return;
}

/**
 * Tribe Events iCal Importer Possible Events List Table
 *
 * Table which holds the events retrieved when searching the iCal in the admin
 *
 * @see buildPossibleEventsListItems::Tribe__Events__Ical_Importer__Main()
 * @see /wp-admin/edit.php?post_type=tribe_events&page=tribe-events-importexport&tab=ical-importer
 *
 * @package Tribe__Events__Ical_Importer__Main
 */
class Tribe__Events__Ical_Importer__Possible_Events_List_Table extends WP_List_Table {

	/*
	 * Get a list of columns.
	 *
	 * @return array
	 */
	public function get_columns() {
		return array(
			'cb'          => '<input type="checkbox" />',
			'start_date'  => __( 'Start Date', 'tribe-events-ical-importer' ),
			'end_date'    => __( 'End Date', 'tribe-events-ical-importer' ),
			'event'       => __( 'Event', 'tribe-events-ical-importer' ),
		);
	}

	/**
	 * Get Column Info
	 *
	 * Specify the columns available on this table
	 *
	 * @return array
	 */
	public function get_column_info() {

		$columns = $this->get_columns();
		if ( Tribe__Events__Ical_Importer__Main::is_search_for_recurring() ){
			unset( $columns[ 'cb' ] );
		}

		$this->_column_headers = array( $columns, array(), array() );

		// compatibility with WordPress 4.3+
		if ( method_exists( $this, 'get_primary_column_name' ) ) {
			$this->_column_headers[] = $this->get_primary_column_name();
		}

		return $this->_column_headers;
	}


	/**
	 * Column CB
	 *
	 * Generate the output for the checkbox column
	 *
	 * @return void
	 */
	public function column_cb( $item ) {
		?>
		<input type="checkbox" name="tribe_events_importexport_events_to_import[]" value="<?php echo esc_attr( $item['cb'] ); ?>" />
		<?php
	}


	/**
	 * Column Default
	 *
	 * Generate the output of any columns which don't need special outputs
	 *
	 * @return void
	 */
	public function column_default( $item, $column ) {
		echo $item[ $column ];
	}
}
