<?php
// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( class_exists( 'Tribe__Events__Ical_Importer__Saved_Imports_List_Table' ) ) {
	return;
}

/**
 * Tribe Events iCal Importer Saved Imports List Table
 *
 * Table which holds the saved imports on the Import:iCal settings page
 *
 * @see /wp-admin/edit.php?post_type=tribe_events&page=tribe-events-importexport&tab=ical-importer
 *
 * @package Tribe__Events__Ical_Importer__Main
 *
 */
class Tribe__Events__Ical_Importer__Saved_Imports_List_Table extends WP_List_Table {

	/**
	 * Get a list of columns.
	 *
	 * @return array
	 */
	public function get_columns() {
		return array(
			'cb'               => '<input type="checkbox" />',
			'domain'           => __( 'Domain', 'tribe-events-ical-importer' ),
			'location'         => __( 'Location', 'tribe-events-ical-importer' ),
			'radius'           => __( 'Radius', 'tribe-events-ical-importer' ),
			'keywords'         => __( 'Keywords', 'tribe-events-ical-importer' ),
			'import_category'  => __( 'Category', 'tribe-events-ical-importer' ),
			'initiated'        => __( 'Initiated', 'tribe-events-ical-importer' ),
			'last_update'      => __( 'Last Update', 'tribe-events-ical-importer' ),
			'schedule'         => __( 'Frequency', 'tribe-events-ical-importer' ),
			'number_imported'  => __( 'Total # Imported', 'tribe-events-ical-importer' ),
		);
	}

	/**
	 * Get Column Info
	 *
	 * Specify the columns available on this table
	 *
	 * @return array
	 */
	public function get_column_info() {
		$this->_column_headers = array( $this->get_columns(), array(), array() );

		// compatibility with WordPress 4.3+
		if ( method_exists( $this, 'get_primary_column_name' ) ) {
			$this->_column_headers[] = $this->get_primary_column_name();
		}

		return $this->_column_headers;
	}


	/**
	 * Column CB
	 *
	 * Generate the output for the checkbox column
	 * @param $item
	 * @return voi
	 */
	public function column_cb( $item ) {
		?>
		<input type="checkbox" name="tribe_events_saved_import[]" value="<?php echo esc_attr( $item['cb'] ); ?>" />
		<?php

	}


	public function column_domain( $item ) {
		$this->column_default( $item, 'domain' );

		$actions = array(
			'edit' => '<a href="javascript:void(0)" class="edit-saved-import" data-id="' . esc_attr( $item[ 'cb' ] ) . '">' . __( 'edit' ). '</a>',
		);

		echo $this->row_actions( $actions );
	}


	/**
	 * Column Default
	 *
	 * Generate the output of any columns which don't need special outputs
	 * @param $item
	 * @param $column
	 * @return void
	 */
	public function column_default( $item, $column ) {
		echo $item[ $column ];
	}

	/**
	* Single Row
	*
	* Generates content for a single row of the table
 	*
	* @param object $item The current item
	*/
	public function single_row( $item ) {
		static $row_class = '';
		$title = '';
		$row_class = ( $row_class == '' ? ' class="alternate"' : '' );

		if ( Tribe__Events__Ical_Importer__Recurring_Imports::get_instance()->get_failed_recurring_imports( $item[ 'key' ] ) ){
			if ( $row_class == ' class="alternate"' ){
				$row_class = ' class="alternate tribe-error-notice"';
			} else {
				$row_class = ' class="tribe-error-notice"';
			}

			$title = ' title="' . __( 'Last import failed.', 'tribe-events-ical-importer' ) . '"';

		}

		echo '<tr' . $row_class . $title . '>';
			$this->single_row_columns( $item );
		echo '</tr>';
	}



    /**
	 * Build Saved Import Row
	 *
	 * Takes care of any data adjustments before a saved import is displayed in the table
	 *
	 * @see self::SavedImportsTable()
	 *
	 * @param array $saved_import
	 * @param int $key - position in the saved imports
	 *
	 * @return array
	 *
	 */
	public function buildSavedImportRow( $saved_import, $key ) {

		$saved_import[ 'cb' ] = $key;

		if ( empty( $saved_import['domain'] ) ){
			$saved_import['domain'] = '';
		}

		if ( ! empty( $saved_import['radius'] ) ) {
			$saved_import['radius'] = Tribe__Events__Ical_Importer__Main::kmToMilesMaybeConvert( $saved_import['radius'] );
		}

		if ( ! empty( $saved_import['import_category'] ) ) {
			$saved_import['import_category'] = get_term( $saved_import['import_category'], Tribe__Events__Main::TAXONOMY )->name;
		}

		$date_format = get_option( 'date_format' );

		$saved_import[ 'initiated' ] = date( $date_format, strtotime( $saved_import[ 'initiated' ] ) );

		if ( $saved_import[ 'last_update' ] == '' ){
			$saved_import[ 'last_update' ] = __( 'Never Run', 'tribe-events-ical-importer' );
		} else {
			$saved_import[ 'last_update' ] = date( $date_format . ' h:i', strtotime( $saved_import[ 'last_update' ] ) );
		}


        $cron_schedules = wp_get_schedules();
		if ( ! empty( $cron_schedules[ $saved_import['schedule'] ] ) ) {
			$saved_import[ 'schedule' ] = $cron_schedules[ $saved_import[ 'schedule' ] ][ 'display' ];
		} else {
			$saved_import[ 'schedule' ] = __( 'Never', 'tribe-events-ical-importer' );
		}

	    //turn the # imported into a link
		if ( ! empty( $saved_import['key'] ) ) {
			$url = admin_url( 'edit.php' ) . '?post_type=' . Tribe__Events__Main::POSTTYPE . '&saved_import=' . urlencode( $saved_import['key'] );
			$saved_import['number_imported'] = '<a target="_blank" href="'. $url . '">'. $saved_import['number_imported'].'</a>';
		}

		$saved_import = array_map( 'stripslashes', $saved_import );

		return $saved_import;
	}

}