/**
 * Import Form Js
 *
 * @uses /wp-admin/edit.php?post_type=tribe_events&page=tribe-events-importexport&tab=ical-importer
 */
jQuery(function($) {
	var pluginSlug = tribeIcalImportPluginSlug;
	TribeImporterIcal.pluginSlug = tribeIcalImportPluginSlug;

	//setup date pickers
	$(".date-picker").datepicker( tribe_datepicker_opts );

	//Search Button is Clicked
	$("#tribe-events-ical-search-submit").click(function() {
		TribeImporterIcal.Search();
	});

	//load more link clicked
	$("#tribe-events-importexport-" + pluginSlug + "-load-more").click(function() {
		TribeImporterIcal.loadEvents();
		return false;
	});

	//File Choose button is clicked
	$("#tribe-events-ical-upload").click(function() {
		TribeImporterIcal.icsFileUploader();
	});

	//Import Type is changed
	$( '#tribe-events-importexport-import-schedule' ).change( function(){
		TribeImporterIcal.showForm( $(this ).find( 'option:selected' ).val() );
	});

	//Source is changed
	$( '#ical-source' ).change( function(){
		TribeImporterIcal.showUploadButton( $(this ).find( 'option:selected' ).val() );
	});

	//Save Import button is clicked
	$('#tribe-import-ical-wrap').on( "click", "#tribe-events-import-auto-import-save", function() {
		TribeImporterIcal.saveImportQuery();
		return false;
	});

	//Delete Checked Saved Imports is clicked
	$("#tribe-events-ical-saved-imports-delete-checked").click( function() {
		TribeImporterIcal.importQueryDeleteChecked();
		return false;
	});

	//Delete Checked Saved Imports is clicked
	$("#tribe-events-ical-saved-imports-import-checked").click( function() {
		TribeImporterIcal.importQueryRunChecked();
		return false;
	});


	//Import Checked Button clicked
	$('#tribe-import-ical-wrap').on( "click", "#tribe-events-importexport-import-submit", function() {
		TribeImporterIcal.importCheckedEvents();
		return false;
	});

	//Import All Button clicked
	$('#tribe-import-ical-wrap').on( "click", "#tribe-events-importexport-import-all", function() {
		TribeImporterIcal.importAllEvents( $(this ).data( 'count' ) );
		return false;
	});

	//Clear button is clicked
	$("#tribe-events-ical-clear").click( function() {
		TribeImporterIcal.clearForm();
		return false;
	});

	//edit link clicked on Saved Recurring Imports
	$('.edit-saved-import' ).click( function(){
		TribeImporterIcal.showEditRecurringImportForm( $(this) );
	});

});

$t = jQuery.noConflict();

/**
 * Tribe Importer iCal
 *
 * Main object for the Tribe Events iCal Importer Plugin
 *
 *
 */
var TribeImporterIcal = {

	/**
	 * Plugin Slug
	 *
	 * Holds this plugins slug
	 *
	 * @var string
	 */
	pluginSlug : '',

	/**
	 * Page
	 *
	 * Keep track of page or events
	 *
	 * @var int
	 */
	paged : 1,

	/**
	 * Total Count
	 *
	 * The total count of events returned from search
	 *
	 * @var int
	 */
	total_count : 1,

	/**
	 * Get Search Form Data
	 *
	 * Returns the values set in the search form
	 *
	 */
	getSearchFormData : function() {
		var data = {
			url                 : $t("#tribe-events-ical-url").val(),
			location            : $t("#tribe-events-ical-location").val(),
			radius              : $t("#tribe-events-ical-radius").val(),
			category            : $t("#tribe-events-ical-category").val(),
			start               : $t("#tribe-events-ical-startdate").val(),
			keywords            : $t("#tribe-events-ical-keywords").val(),
			schedule            : $t('#tribe-events-importexport-import-schedule').val(),
			recurring_overwrite : $t('#tribe-events-importexport-import-recurring_overwrite').is( ':checked' ) ? 'checked' : '',
			post_status         : $t('#tribe-events-importexport-import-status').val(),
			import_category     : $t('#tribe-events-importexport-import-category').val()
		};

		return data;
	},


	showEditRecurringImportForm : function( el ){
		var $selects = [ "import_category", "post_status", "schedule", "radius" ];
		var $imports = JSON.parse( $t( '#tribe-import-saved-items-json' ).html() );
		var $import = $imports[ el.data( 'id' ) ];

		var $form = $t( '#edit-saved-recurring' );
		var $content = $t( $form.html() );

		for(prop in $import ){
			if( $selects.indexOf( prop ) != -1 ){
				var $select = $content.find( 'select[name="'+prop+'"]' );
				$select.find( 'option' ).attr( 'selected', false );
				$select.find( 'option[value="'+$import[ prop ]+'"]' ).attr( 'selected', true );

			} else {
				$content = $content.html( $content.html().replace( '{{' + prop + '}}', $import[prop] ) );
			}
		}

		var $placeholder = $t( '#edit-saved-recurring-placeholder' ).html( $content.html() );

		var box_height = jQuery( window ).height() - 100;
		box_height = 750 > box_height ? box_height : 750;

		var box_width = jQuery( window ).width() - 100;
		box_width = 500 > box_width ? box_width : 500;

		tb_show( tribeIcalImportConfig.local.edit_recurring, '#TB_inline?width=' + box_width + '&height=' + box_height + '&inlineId=edit-saved-recurring-placeholder' );

		setTimeout( function(){
			$t('.date-picker' ).datepicker( tribe_datepicker_opts );
		},1000 );

	},


	showForm : function( v ){
		if( v != 0 ){
			$t( '#tribe-events-importexport-import-form form' ).show();
		} else {
			$t( '#tribe-events-importexport-import-form form' ).hide();
		}
	},


	clearForm : function(){
		$t( '#tribe-events-importexport-new-import-form .tribe-error-notice' ).hide();
		$t( '#tribe-events-importexport-import-form form' ).hide();
		$t( '#tribe-events-ical-upload' ).hide();
		$t("#tribe-events-import-list-wrapper" ).html('');

		$t("#tribe-events-ical-url").val('');
		$t("#tribe-events-ical-location").val('');
		$t("#tribe-events-ical-startdate").val( $t("#tribe-events-ical-startdate" ).data('default') );
		$t("#tribe-events-ical-keywords").val('');

		$t("#ical-source").prop( 'selectedIndex', 0 );
		$t("#tribe-events-ical-radius").prop( 'selectedIndex', 0 );
		$t('#tribe-events-importexport-import-schedule').prop( {'selectedIndex': 0, 'disabled' : false } );

	},


	showUploadButton : function( v ){
		var $select = $t( '#tribe-events-importexport-import-schedule' );

		if( v == 'file' ){
			$select.prop( 'disabled', true );
			$select.find( '.recurring' ).prop( 'selected', false );
			$select.find( '.single' ).prop( 'selected', true );
			$t( '#tribe-events-ical-upload' ).show();
		} else {
			$select.prop( 'disabled', false );
			$t( '#tribe-events-ical-upload' ).hide();
		}
	},


    /**
     * Parse Ajax Response
     *
     * Try to turn the response into an object
     * If fail display an error and console.log
     *
     * @param string|object response
     *
     * @return obj|bool - false on failure
     *
     */
	parseAjaxResponse : function( response ){
		$t( '#tribe-events-importexport-save-import-spinner' ).removeClass( 'is-active' );

		// If the response is an object let's return it directly
		if ( 'object' === typeof response ) {
			return response;
		}

		if ( 'string' !== $t.type( response ) ) {
			return response;
		}

		// Otherwise let's try parsing from JSON into an POJO
		try {
			var data = jQuery.parseJSON( response );
		} catch( err ) {
			TribeImporterIcal.errorMessages( true );
			console.info( 'TribeImporterIcal.parseAjaxResponse failed' );
			console.log( response );

			return false;
		}

		return data;
	},


	/**
	 * Ics File Uploader
	 *
	 * Handle the media uploader process for the ics file select
	 *
	 * @return void
	 */
	icsFileUploader : function() {
		var custom_uploader = wp.media({
			title : 'Choose .ics File',
			button : {
				text : 'Choose .ics File'
			},
			library : {
				type : 'text/calendar'
			},
			multiple : false
		}).on('select', function() {
			var items = custom_uploader.state().get('selection');
			var attachment = items.models[0].toJSON();

			$t('#tribe-events-ical-url').val(attachment.url);

		}).open();

	},

	/**
	 * Search
	 *
	 * Init the search when the button is clicked
	 */
	Search : function() {
		$t('#tribe-events-importexport-' + TribeImporterIcal.pluginSlug + '-load-more').hide();
		this.paged = 1;
		this.loadEvents();
	},


	/**
	 * Error Messages
	 *
	 * Display the appropriate error message and return true if displayed an error
	 *
	 * @param bool [general] - true will display general error
	 *
	 * @return bool
	 */
	errorMessages : function( general ){
		var args = this.getSearchFormData();

		$t( '#tribe-events-importexport-import-form .tribe-error-notice' ).hide();

		if( general == true ){
			$t( '#tribe_error_general_error' ).show();
			$t('html, body').animate({
				scrollTop: $t( '#tribe_error_general_error' ).offset().top - 75
			}, 1000);
			return;
		}


		if (!args.url && !args.file) {
			$t("#tribe_error_no_ical").show();
			return true;
		} else {
			$t("#tribe_error_no_ical").hide();
			return false;
		}

	},


	/**
	 * Save Import Query
	 *
	 * Uses ajax to save the current query
	 */
	saveImportQuery : function() {
		var args = this.getSearchFormData();

		if( this.errorMessages() ) return;

		args.action = 'tribe_events_' + this.pluginSlug + '_save_import_query';
		args._wpnonce = icalImportNonce;

		$t.ajax({
			type : "POST",
			url : ajaxurl,
			data : args,
			beforeSend : function() {
				$t( '#tribe-events-importexport-save-import-spinner' ).addClass( 'is-active' );
			},
			error: function( response ) {
				TribeImporterIcal.errorMessages( true );
				console.info( 'TribeImporterIcal.saveImportQuery failed' );
				console.log( response );
			},
			success : function( response ) {
				data = TribeImporterIcal.parseAjaxResponse( response );
				if( data == false ) return;

				TribeImporterIcal.redirect( "&new_saved_import=1" );
			}
		});
	},


	/**
	 * Import Query Run Checked
	 *
	 * Delete the checked Saved Imports from the database and page output
	 *
	 *
	 */
	importQueryRunChecked : function(){
		var items = [];

		$t("[name='tribe_events_saved_import[]']:checked").each( function(){
			items.push( $t(this).val() );
		});

		if( !items.length ){
		    $t( '#tribe_error_no_ical_saved_boxes_checked' ).show();
			return;
		} else {
			$t( '#tribe_error_no_ical_saved_boxes_checked' ).hide();
		}

        var args = {};

        args.index = items;
		args.action = 'tribe_events_' + this.pluginSlug + '_run_saved_import_query';
		args._wpnonce = icalImportNonce;

		$t.ajax({
			type : "POST",
			url : ajaxurl,
			data : args,
			beforeSend : function() {
				$t( '#tribe-events-ical-saved-imports-actions-spinner' ).addClass( 'is-active' );
			},
			error: function( response ) {
				TribeImporterIcal.errorMessages( true );
				console.info( 'TribeImporterIcal.importQueryRunChecked failed' );
				console.log( response );
			},
			success : function( response ) {
				data = TribeImporterIcal.parseAjaxResponse( response );
				if( data == false ) return;

				TribeImporterIcal.redirect(
					"&run_saved_import=" + data.success + "&num_events=" + data.num_events + "&upserts=" + data.upserts );
			}
		});

	},


	/**
	 * Import Query Deleted Checked
	 *
	 * Delete the checked Saved Imports from the database and page output
	 *
	 *
	 */
	importQueryDeleteChecked : function(){
		var items = [];

		$t("[name='tribe_events_saved_import[]']:checked").each( function(){
			items.push( $t(this).val() );
		});

		if( !items.length ){
		    $t( '#tribe_error_no_ical_saved_boxes_checked' ).show();
			return;
		} else {
			$t( '#tribe_error_no_ical_saved_boxes_checked' ).hide();
		}

        var args = {};

        args.index = items;
		args.action = 'tribe_events_' + this.pluginSlug + '_delete_saved_import_query';
		args._wpnonce = icalImportNonce;

		$t.ajax({
			type : "POST",
			url : ajaxurl,
			data : args,
			beforeSend : function() {
				$t( '#tribe-events-ical-saved-imports-actions-spinner' ).addClass( 'is-active' );
			},
			error: function( response ) {
				TribeImporterIcal.errorMessages( true );
				console.info( 'TribeImporterIcal.importQueryDeleteChecked failed' );
				console.log( response );
			},
			success : function( response ) {
				data = TribeImporterIcal.parseAjaxResponse( response );
				if( data == false ) return;

				TribeImporterIcal.redirect( "&deleted_saved_import="+data.success );

			}
		});

	},

	/**
	 * Redirect
	 *
	 * Redirects to current page along with an appended query arg for messages
	 *
	 * @param string queryArgs
	 *
	 * @return void
	 */
	redirect : function( queryArgs ){
		var url = tribeIcalImportUrl;
		url += queryArgs;
		window.location.href = url;

	},


	/**
	 * Init Page Links
	 *
	 * Run the methods to setup all pagination links
	 *
	 */
	initPageLinks : function() {
		TribeImporterIcal.checkAllBox();
		TribeImporterIcal.firstPageLink();
		TribeImporterIcal.lastPageLink();
		TribeImporterIcal.nextPageLink();
		TribeImporterIcal.prevPageLink();

	},

	/**
	 * Check All Box
	 *
	 * All the check-all box to work
	 *
	 * @uses runs from initPageLinks
	 *
	 */
	checkAllBox : function(){
		$t( '#cb-select-all-1,#cb-select-all-2' ).click( function(){
			var c = $t(this);
			if( c.prop( 'checked' ) ){
				c.parents().eq(4).find( '.check-column input[type="checkbox"]' ).prop( "checked", true );
			} else {
				c.parents().eq(4).find( '.check-column input[type="checkbox"]' ).prop( "checked", false );
			}
		});
	},

	/**
	 * First Page Link
	 *
	 * Sets up the first page link to work via ajax
	 */
	firstPageLink : function() {
		$t('.pagination-links .first-page').click(function() {
			TribeImporterIcal.paged = 1;
			TribeImporterIcal.loadEvents();
			return false;
		});
	},

	/**
	 * Last Page Link
	 *
	 * Sets up the last page link to work via ajax
	 */
	lastPageLink : function() {
		$t('.pagination-links .last-page').click(function() {
			TribeImporterIcal.paged = TribeImporterIcal.total_count;
			TribeImporterIcal.loadEvents();
			return false;
		});
	},

	/**
	 * Next Page Link
	 *
	 * Sets up the next page link to work via ajax
	 */
	nextPageLink : function() {
		$t('.pagination-links .next-page').click(function() {
			TribeImporterIcal.paged++;
			TribeImporterIcal.loadEvents();
			return false;
		});
	},

	/**
	 * Prev Page Link
	 *
	 * Sets up the previous page link to work via ajax
	 */
	prevPageLink : function() {
		$t('.pagination-links .prev-page').click(function() {
			TribeImporterIcal.paged--;
			TribeImporterIcal.loadEvents();
			return false;
		});

	},

	/**
	 * Load More Events
	 *
	 * Uses ajax to load matching events
	 */
	loadEvents : function() {
		var args = TribeImporterIcal.getSearchFormData();
		args.paged = TribeImporterIcal.paged;
		args.action = 'tribe_events_' + this.pluginSlug + '_get_possible_events';
		args.manual = true;

		if( this.errorMessages() ) return;

		$t.ajax({
			type : "POST",
			url : ajaxurl,
			data : args,
			dataType : "json",
			beforeSend : function() {
				$t('#tribe-events-importexport-search-spinner').addClass( 'is-active' );
			},
			error: function( response ) {
				TribeImporterIcal.errorMessages( true );
				console.info( 'TribeImporterIcal.loadEvents failed' );
				console.log( response );
			},
			success : function( response ) {

				$t("#tribe-events-import-list-wrapper").empty();
				$t('#tribe-events-importexport-search-spinner').removeClass( 'is-active' );

				var data = TribeImporterIcal.parseAjaxResponse( response );
				if( data == false ) return;

				if( typeof( data.error ) != "undefined" ){
					$t( '#tribe_error_no_events_returned p' ).text( data.error );
					$t( '#tribe_error_no_events_returned' ).show();
				} else {
					$t( '#tribe_error_no_events_returned' ).hide();
				}

				$t('#tribe-events-import-list-wrapper').prepend(data.body);

				TribeImporterIcal.total_count = Math.ceil(data.count / 30);

				TribeImporterIcal.initPageLinks();

				var $all_btn = $t('#tribe-events-importexport-import-all');

				if( $all_btn.length ){
					$all_btn.data( 'count', data.count );
					if ( typeof( data.count ) == 'undefined') {
						$all_btn.val( $t('#tribe-events-importexport-import-all').val().replace(/\([^\)]*\)/, '(0)') );
					} else {
						$all_btn.val( $t('#tribe-events-importexport-import-all').val().replace(/\([^\)]*\)/, '(' + data.count + ')') );
					}
				}
			}
		});

	},

	/**
	 * Import All Events
	 *
	 * Uses ajax to import all events
	 *
	 */
	importAllEvents : function( count ) {
		var args = TribeImporterIcal.getSearchFormData();
		args.action = 'tribe_events_' + this.pluginSlug + '_import_all_events';
		args._wpnonce = icalImportNonce;
		args.expected_count = count;

		$t.ajax({
			type : "POST",
			url : ajaxurl,
			data : args,
			beforeSend : function(){
				$t( '#tribe-events-importexport-import-all-spinner' ).addClass( 'is-active' );
			},
			error: function( response ) {
				TribeImporterIcal.errorMessages( true );
				console.info( 'TribeImporterIcal.importAllEvents failed' );
				console.log( response );
			},
			success : function( response ) {
				$t( '#tribe-events-importexport-import-all-spinner' ).removeClass( 'is-active' );

				data = TribeImporterIcal.parseAjaxResponse( response );
				if( data == false ) return;

				TribeImporterIcal.redirect( '&' + $t.param( data ) );
			}
		});
	},


	/**
	 * Import Checked Events
	 *
	 * Import the events which have been checked for import
	 *
	 *
	 */
	importCheckedEvents : function() {
		var args = this.getSearchFormData();
		var events_to_import = [];
		$t("[name='tribe_events_importexport_events_to_import[]']:checked").each( function(){
			events_to_import.push( $t(this).val() );
		});

		if( events_to_import.length == 0 ){
			$t( '#tribe_error_no_event_boxes_checked' ).show();
			return;
		} else {
			$t( '#tribe_error_no_event_boxes_checked' ).hide();
		}

		args.events_to_import = events_to_import;
		args.action = 'tribe_events_' + this.pluginSlug + '_import_checked_events';
		args._wpnonce = icalImportNonce;

		$t.ajax({
			type : "POST",
			url : ajaxurl,
			data : args,
			beforeSend : function() {
				$t( '#tribe-events-importexport-import-checked-spinner' ).addClass( 'is-active' );
			},
			error: function( response ) {
				TribeImporterIcal.errorMessages( true );
				console.info( 'TribeImporterIcal.importCheckedEvents failed' );
				console.log( response );
			},
			success : function( response ) {
				data = TribeImporterIcal.parseAjaxResponse( response );
				if( data == false ) return;

				TribeImporterIcal.redirect( '&' + $t.param( data ) );
			}
		});
	}

};
//-- End TribeImporterIcal

