<?php
/*
Plugin Name: The Events Calendar: iCal Importer
Description: Import events into The Events Calendar from an iCal file or feed.
Version: 4.2.3
Author: Modern Tribe, Inc.
Author URI: http://tri.be
License: GPLv2
Text Domain: tribe-events-ical-importer
*/

/**
 * @package Tribe__Events__Ical_Importer__Main
 * @author Modern Tribe, Inc.
 * @version 3.9
 */

/*
Copyright 2014 Modern Tribe Inc. and the Collaborators

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

require( 'src/functions/template-tags.php' );

add_action( 'plugins_loaded', 'tribe_events_ical_load', 2 );

/**
 * Tribe Events iCal Importer Load
 *
 * Function used to load the iCal Importer.
 *
 *
 * @return void
 */
function tribe_events_ical_load() {
	tribe_events_ical_autoloading();

	$classes_exist = class_exists( 'Tribe__Events__Main' ) && class_exists( 'Tribe__Events__Ical_Importer__Main' );

	$mopath = dirname( plugin_basename( __FILE__ ) ) . '/lang';
	$domain = 'tribe-events-ical-importer';

	// If we don't have Common classes load the old fashioned way
	if ( ! class_exists( 'Tribe__Main' ) ) {
		load_plugin_textdomain( $domain, false, $mopath );
	} else {
		// This will load `wp-content/languages/plugins` files first
		Tribe__Main::instance()->load_text_domain( $domain, $mopath );
	}

	if ( $classes_exist && defined( 'Tribe__Events__Main::VERSION' ) ) {

		Tribe__Events__Ical_Importer__Main::init();

		//we don't load on the front end
		if ( Tribe__Events__Ical_Importer__Main::should_bootstrap() ) {
			require( 'vendor/iCalcreator_3.0/iCalcreator.php' );
			Tribe__Events__Importer__Registrar::init();
			require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
			Tribe__Events__Ical_Importer__Filters::init();
			Tribe__Events__Ical_Importer__Recurring_Imports::init();

			new Tribe__Events__Ical_Importer__PUE( __FILE__ );

		} else {
			//filter bar init
			add_action( 'tribe_events_filters_create_filters', 'tribe_events_ical_importer_filter_bar_init' );
		}
	} else {
		add_action( 'admin_notices', 'tribe_events_ical_importer_show_fail_message' );
	}
}

/**
* Tribe Events iCal Importer Filter Bar Init
*
* Init the class to add iCal source filtering to filter bar plugin
*
* @uses Tribe_Events_Ical_Importer_Filter_Bar
*
* @return void
*/
function tribe_events_ical_importer_filter_bar_init() {
	Tribe__Events__Ical_Importer__Filter_Bar::init();
}


/**
 * Tribe Events iCal Importer Show Fail Message
 *
 * Shows message if the plugin can't load due to TEC not being installed.
 *
 * @return void
 */
function tribe_events_ical_importer_show_fail_message() {
	if ( current_user_can( 'activate_plugins' ) ) {
		$url = 'plugin-install.php?tab=plugin-information&plugin=the-events-calendar&TB_iframe=true';
		$title = __( 'The Events Calendar', 'tribe-events-ical-importer' );
		echo '<div class="error"><p>' . sprintf( __( 'To begin using The Events Calendar: iCal Importer, please install the latest version of <a href="%s" class="thickbox" title="%s">The Events Calendar</a>.', 'tribe-events-ical-importer' ), esc_url( $url ), esc_attr( $title ) ) . '</p></div>';
	}
}

register_deactivation_hook( __FILE__, 'tribe_events_ical_deactivate' );
function tribe_events_ical_deactivate() {
	if ( ! class_exists( 'Tribe__Events__Main' ) ) {
		return;
	}
	$recurring = Tribe__Events__Ical_Importer__Recurring_Imports::get_instance();
	$recurring->clear_saved_imports();
}


//wpcli events
if ( defined( 'WP_CLI' ) && WP_CLI ) {
	if ( file_exists( __DIR__ . '/dev/wpcli.php' ) ) {
		require( 'dev/wpcli.php' );
	}
}

/**
 * Requires the autoloader class from the main plugin class and sets up
 * autoloading.
 */
function tribe_events_ical_autoloading() {
	if ( ! class_exists( 'Tribe__Autoloader' ) ) {
		return;
	}
	$autoloader = Tribe__Autoloader::instance();

	$autoloader->register_prefix( 'Tribe__Events__Importer__', dirname( __FILE__ ) . '/src/Tribe' );
	$autoloader->register_prefix( 'Tribe__Events__Ical_Importer__', dirname( __FILE__ ) . '/src/Tribe' );

	// deprecated classes are registered in a class to path fashion
	foreach ( glob( dirname( __FILE__ ) . '/src/deprecated/*.php' ) as $file ) {
		$class_name = str_replace( '.php', '', basename( $file ) );
		$autoloader->register_class( $class_name, $file );
	}
	$autoloader->register_autoloader();
}
